@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -678,6 +678,7 @@ _
             push @l, '$res = _pci_check_args(\%_pci_args);', "\n";
             push @l, '_pci_err($res) if $res->[0] != 200;', "\n";
             push @l, '_pci_debug("args after _pci_check_args: ", \%_pci_args);', "\n" if $args{with_debug};
+            push @l, '_pci_err([500, "Extraneous command-line argument(s): ".join(", ", @ARGV)]) if @ARGV;', "\n";
         }
         push @l, "}\n\n";
 
@@ -840,7 +841,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.21 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-12.
+This document describes version 0.22 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
@@ -866,23 +867,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)   -c (inline)   perl
- run 1 (lite)            9.855+-0.011/s            --               -57.4%        -77.8%         -83.5%                 -85.0%        -88.7% -94.5%
- run --version (lite)    23.108+-0.02/s 134.48+-0.34%                   --        -48.0%         -61.4%                 -64.8%        -73.6% -87.2%
- -c (lite)              44.407+-0.044/s 350.59+-0.69%         92.17+-0.25%            --         -25.8%                 -32.4%        -49.2% -75.3%
- run 1 (inline)             59.8+-1.6/s      507+-16%          158.9+-6.9%    34.7+-3.6%             --                  -8.9%        -31.6% -66.7%
- run --version (inline)    65.7+-0.31/s   566.6+-3.2%          184.3+-1.4%  47.95+-0.71%        9.8+-3%                     --        -24.9% -63.5%
- -c (inline)            87.452+-0.067/s   787.4+-1.2%        278.45+-0.43%  96.93+-0.25%     46.2+-3.9%           33.11+-0.64%            -- -51.4%
- perl                    179.89+-0.33/s  1725.4+-3.9%          678.5+-1.6% 305.11+-0.84%      200.7+-8%            173.8+-1.4% 105.71+-0.41%     --
+                                    Rate  run 1 (lite) run --version (lite)  -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.265+-0.0087/s            --               -60.5%     -82.8%         -88.7%                 -91.0%      -93.7% -97.5%
+ run --version (lite)    33.616+-0.081/s 153.42+-0.63%                   --     -56.4%         -71.5%                 -77.2%      -84.0% -93.6%
+ -c (lite)                  77.1+-0.17/s   481.3+-1.3%        129.37+-0.75%         --         -34.5%                 -47.7%      -63.2% -85.3%
+ run 1 (inline)           117.79+-0.72/s     788+-5.5%          250.4+-2.3%  52.77+-1%             --                 -20.1%      -43.8% -77.5%
+ run --version (inline)     147.5+-1.6/s     1012+-12%          338.7+-4.7% 91.3+-2.1%     25.2+-1.5%                     --      -29.7% -71.8%
+ -c (inline)                209.7+-1.3/s   1480.8+-10%          523.8+-4.2%  172+-1.8%       78+-1.6%             42.2+-1.7%          -- -59.9%
+ perl                       522.8+-1.7/s     3841+-13%         1455.1+-6.2%  578+-2.6%    343.8+-3.1%            254.5+-3.9% 149.3+-1.8%     --
  
  Average times:
-   perl                  :     5.5590ms
-   -c (inline)           :    11.4348ms
-   run --version (inline):    15.2207ms
-   run 1 (inline)        :    16.7224ms
-   -c (lite)             :    22.5190ms
-   run --version (lite)  :    43.2751ms
-   run 1 (lite)          :   101.4713ms
+   perl                  :     1.9128ms
+   -c (inline)           :     4.7687ms
+   run --version (inline):     6.7797ms
+   run 1 (inline)        :     8.4897ms
+   -c (lite)             :    12.9702ms
+   run --version (lite)  :    29.7477ms
+   run 1 (lite)          :    75.3864ms
 
 =head1 FUNCTIONS
 
